from django.db.models import ManyToOneRel, OneToOneRel
from django.db import models
from model_utils.managers import QueryManager

class SoftDeleteMixin(models.Model):
    is_removed = models.BooleanField(default=False, editable=False)

    class Meta:
        abstract = True

    objects = QueryManager(is_removed=False)
    deleted = QueryManager(is_removed=True)
    all_objects = models.Manager()

    def delete(self, using=None, soft=True, *args, **kwargs):
        """
        Soft delete object (set its ``is_removed`` field to True).
        Actually delete object if setting ``soft`` to False.
        """
        if soft:
            self.is_removed = True
            self.save(using=using)
        else:
            return super().delete(using=using, *args, **kwargs)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['django_lc_utils', 'django_lc_utils.migrations']

package_data = \
{'': ['*']}

install_requires = \
['Django>=3.1.13,<4.0.0', 'django-model-utils>=4.2.0,<5.0.0']

setup_kwargs = {
    'name': 'django-lc-utils',
    'version': '0.1.0',
    'description': 'Utilities for Django application',
    'long_description': None,
    'author': 'Tejas Bhandari',
    'author_email': 'tejas@thesummitgrp.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
